/*
 * CodePress color styles for PHP syntax highlighting
 */

b {color:#000080;} /* tags */
big, big b, big em, big ins, big s, strong i, strong i b, strong i s, strong i u, strong i a, strong i a u, strong i s u {color:gray;font-weight:normal;} /* comments */
s, s b, strong s u, strong s cite {color:#5656fa;font-weight:normal;} /* attributes and strings */
strong a, strong a u {color:#006700;font-weight:bold;} /* variables */
em {color:#800080;font-style:normal;} /* style */
ins {color:#800000;} /* script */
strong u {color:#7F0055;font-weight:bold;} /* reserved words */
cite, s cite {color:red;font-weight:bold;} /* <?php and ?> */
