/*
 * CodePress color styles for generic syntax highlighting
 */

b {color:#7F0055;font-weight:bold;} /* reserved words */
u {color:darkblue;font-weight:bold;} /* special words */
i, i b, i s, i u, i em {color:green;font-weight:normal;} /* comments */
s, s b, s em {color:#2A00FF;font-weight:normal;} /* strings */
em {font-weight:bold;} /* special chars */