/* 2 column liquid layout */
#adminmenu {
	float: right;
	clear: right;
	margin-right:-160px;
	margin-left: 5px;
}
body.folded #adminmenu {
	margin-left: 0;
	margin-right: -45px;
}
/* inner 2 column liquid layout */
.inner-sidebar {
	float: left;
	clear: left;
}

.has-right-sidebar #post-body {
	clear:right;
	float:right;
	margin-right:0;
	margin-left:-340px;
}

.has-right-sidebar #post-body-content {
	margin-left: 300px;
	margin-right:0;
}

#wpbody {
	margin-left:0;
	margin-right: 175px;
}
.folded #wpbody {
	margin-left: 0;
	margin-right: 60px;
}
#wpbody-content {
	float: right;
}
/* 2 columns main area */
#col-right {
	float: left;
	clear: left;
}
.wrap {
	margin: 0 5px 0 15px;
}
/* styles for use by people extending the WordPress interface */
body, td, textarea, input, select {
	font-family: Tahoma, arial;
}
.alignleft {
	float: right;
}
.alignright {
	float: left;
}
.subsubsub {
	float: right;
}
.widefat th {
	text-align: right;
}
.widefat th input {
	margin: 0 8px 0 0;
}
.wrap h2 {
	font-family: arial;
	padding: 14px 0 3px 15px;
}
.wrap h2.long-header {
	padding-left: 0;
}
.updated, .error {
	clear: both;
}

.screen-reader-text, .screen-reader-text span {
	left:auto;
	right:-1000em;
}
}